@@ -26,7 +26,6 @@
 #include <kwallet.h>
 #include <kxmlguiwindow.h>
 #include "registercreateactionmethod.h"
-#include <QStringList>
 #include <QLabel>
 
 class KActionCollection;
@@ -42,20 +41,18 @@ class KWalletEditor : public QWidget, public Ui::WalletWidget
     Q_OBJECT
 
 public:
-    KWalletEditor(QWidget *parent, const char *name = 0);
+    explicit KWalletEditor(QWidget *parent, const QString &name = QString());
     virtual ~KWalletEditor();
 
     void setWallet(KWallet::Wallet *wallet, bool isPath = false);
-    bool isOpen() const
-    {
-        return _w != 0L;
-    }
+    bool isOpen() const;
 
+    bool hasUnsavedChanges() const;
     void setNewWallet(bool newWallet);
 
 protected:
-    virtual void hideEvent(QHideEvent *);
-    virtual void showEvent(QShowEvent *);
+    void hideEvent(QHideEvent *) Q_DECL_OVERRIDE;
+    void showEvent(QShowEvent *) Q_DECL_OVERRIDE;
 
 public slots:
     void walletClosed();
@@ -130,6 +127,7 @@ private:
     KTreeWidgetSearchLine *_searchLine;
     static QAction *_alwaysShowContentsAction, *_alwaysHideContentsAction;
     bool _alwaysShowContents;
+    bool _hasUnsavedChanges;
 };
 
 #endif
