@@ -30,7 +30,6 @@
 
 #include <QApplication>
 #include <QClipboard>
-#include <QDebug>
 #include <QItemDelegate>
 #include <QFocusEvent>
 #include <QKeyEvent>
@@ -48,7 +47,7 @@ public:
     }
 
 protected:
-    virtual void focusOutEvent(QFocusEvent *e)
+    void focusOutEvent(QFocusEvent *e) Q_DECL_OVERRIDE
     {
         if (e->reason() == Qt::PopupFocusReason) {
             // TODO: It seems we only get here if we're disturbed
@@ -58,7 +57,7 @@ protected:
 
         close();
     }
-    virtual void keyPressEvent(QKeyEvent *e)
+    void keyPressEvent(QKeyEvent *e) Q_DECL_OVERRIDE
     {
         if (e->key() == Qt::Key_Escape) {
             e->accept();
@@ -68,7 +67,7 @@ protected:
             QTextEdit::keyPressEvent(e);
         }
     }
-    virtual void contextMenuEvent(QContextMenuEvent *event)
+    void contextMenuEvent(QContextMenuEvent *event) Q_DECL_OVERRIDE
     {
         QMenu *menu = createStandardContextMenu();
         popup = menu;
@@ -86,7 +85,7 @@ public:
     {
     }
 
-    QWidget *createEditor(QWidget *parentWidget, const QStyleOptionViewItem &option, const QModelIndex &index) const
+    QWidget *createEditor(QWidget *parentWidget, const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE
     {
         if (index.column() != 2) {
             return QItemDelegate::createEditor(parentWidget, option, index);
@@ -96,7 +95,7 @@ public:
         return new InlineEditor(mapEditor);
     }
 
-    void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const
+    void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE
     {
         if (dynamic_cast<InlineEditor *>(editor)) {
             KWMapEditor *mapEditor = static_cast<KWMapEditor *>(parent());
@@ -108,7 +107,7 @@ public:
         }
     }
 
-    void setEditorData(QWidget *editor, const QModelIndex &index) const
+    void setEditorData(QWidget *editor, const QModelIndex &index) const Q_DECL_OVERRIDE
     {
         InlineEditor *e = dynamic_cast<InlineEditor *>(editor);
         if (e) {
@@ -119,7 +118,7 @@ public:
         }
     }
 
-    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
+    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const Q_DECL_OVERRIDE
     {
         InlineEditor *e = dynamic_cast<InlineEditor *>(editor);
         if (e) {
@@ -157,7 +156,7 @@ void KWMapEditor::reload()
         setRowCount(_map.count());
         for (int x = row; x < rowCount(); ++x) {
             QToolButton *b = new QToolButton(this);
-            b->setIcon(QIcon::fromTheme("edit-delete"));
+            b->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
             b->setToolTip(i18n("Delete Entry"));
             connect(b, &QToolButton::clicked, this, &KWMapEditor::erase);
             setCellWidget(x, 0, b);
@@ -170,7 +169,7 @@ void KWMapEditor::reload()
     }
 
     row = 0;
-    for (QMap<QString, QString>::Iterator it = _map.begin(); it != _map.end(); ++it) {
+    for (QMap<QString, QString>::Iterator it = _map.begin(), end = _map.end(); it != end; ++it) {
         item(row, 1)->setText(it.key());
         item(row, 2)->setText(it.value());
         row++;
@@ -208,7 +207,7 @@ void KWMapEditor::addEntry()
     int x = rowCount();
     insertRow(x);
     QToolButton *b = new QToolButton(this);
-    b->setIcon(QIcon::fromTheme("edit-delete"));
+    b->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
     b->setToolTip(i18n("Delete Entry"));
     connect(b, &QToolButton::clicked, this, &KWMapEditor::erase);
     setCellWidget(x, 0, b);
@@ -232,6 +231,7 @@ void KWMapEditor::contextMenu(const QPoint &pos)
     m->addAction(i18n("&New Entry"), this, SLOT(addEntry()));
     m->addAction(_copyAct);
     m->popup(mapToGlobal(pos));
+    delete m;
 }
 
 void KWMapEditor::copy()
